==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/openshift/api/model/BuildFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface BuildFluent<A extends BuildFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public String getKind();
    public A withKind(String kind);
    public ObjectMeta getMetadata();
    public A withMetadata(ObjectMeta metadata);
    public BuildFluent.MetadataNested<A> withNewMetadata();
    public BuildFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public BuildFluent.MetadataNested<A> editMetadata();
    public BuildFluent.MetadataNested<A> editOrNewMetadata();
    public BuildFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public BuildSpec getSpec();
    public A withSpec(BuildSpec spec);
    public BuildFluent.SpecNested<A> withNewSpec();
    public BuildFluent.SpecNested<A> withNewSpecLike(BuildSpec item);
    public BuildFluent.SpecNested<A> editSpec();
    public BuildFluent.SpecNested<A> editOrNewSpec();
    public BuildFluent.SpecNested<A> editOrNewSpecLike(BuildSpec item);
    public BuildStatus getStatus();
    public A withStatus(BuildStatus status);
    public BuildFluent.StatusNested<A> withNewStatus();
    public BuildFluent.StatusNested<A> withNewStatusLike(BuildStatus item);
    public BuildFluent.StatusNested<A> editStatus();
    public BuildFluent.StatusNested<A> editOrNewStatus();
    public BuildFluent.StatusNested<A> editOrNewStatusLike(BuildStatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<BuildFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BuildSpecFluent<BuildFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BuildStatusFluent<BuildFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> kubernetes-model-2.0.9-sources.jar: annotations/io/fabric8/openshift/api/model/BuildFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;
import java.util.Map;

public interface BuildFluent<A extends BuildFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public BuildFluent.MetadataNested<A> withNewMetadata();
    public BuildFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public BuildFluent.MetadataNested<A> editMetadata();
    public BuildFluent.MetadataNested<A> editOrNewMetadata();
    public BuildFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 */
@Deprecated public BuildSpec getSpec();
    public BuildSpec buildSpec();
    public A withSpec(BuildSpec spec);
    public Boolean hasSpec();
    public BuildFluent.SpecNested<A> withNewSpec();
    public BuildFluent.SpecNested<A> withNewSpecLike(BuildSpec item);
    public BuildFluent.SpecNested<A> editSpec();
    public BuildFluent.SpecNested<A> editOrNewSpec();
    public BuildFluent.SpecNested<A> editOrNewSpecLike(BuildSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 */
@Deprecated public BuildStatus getStatus();
    public BuildStatus buildStatus();
    public A withStatus(BuildStatus status);
    public Boolean hasStatus();
    public BuildFluent.StatusNested<A> withNewStatus();
    public BuildFluent.StatusNested<A> withNewStatusLike(BuildStatus item);
    public BuildFluent.StatusNested<A> editStatus();
    public BuildFluent.StatusNested<A> editOrNewStatus();
    public BuildFluent.StatusNested<A> editOrNewStatusLike(BuildStatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<BuildFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BuildSpecFluent<BuildFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BuildStatusFluent<BuildFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
